pub fn create(ctx: &Context, name: &str, args: StashArgs) -> StashResultExpand description
Registers a new stash resource with the given unique name and arguments.
pub fn create(ctx: &Context, name: &str, args: StashArgs) -> StashResultRegisters a new stash resource with the given unique name and arguments.