pub fn create_with_options(
ctx: &Context,
name: &str,
args: StashArgs,
options: CustomResourceOptions,
) -> StashResultExpand description
Same as create, but with additional generic options that control registration behavior.
pub fn create_with_options(
ctx: &Context,
name: &str,
args: StashArgs,
options: CustomResourceOptions,
) -> StashResultSame as create, but with additional generic options that control registration behavior.