pub struct StashResult {
pub id: Output<String>,
pub urn: Output<String>,
pub input: Output<PulumiAny>,
pub output: Output<PulumiAny>,
}Expand description
Output object returned from stash creation.
Fields
id: Output<String>Pulumi ID is the provider-assigned unique ID for this managed resource. It is set during deployments and may be missing (unknown) during planning phases.
urn: Output<String>Pulumi URN is the stable logical identity of this resource in the Pulumi stack.
input: Output<PulumiAny>The most recent value passed to the stash resource.
output: Output<PulumiAny>The value saved in state for the stash.